@@ -9,14 +9,7 @@ static void _destroy_pzk_dequeue_node(pzk_dequeue_node_t* node) {
     if (node) free(node);
 }
 
-pzk_dequeue_t* new_pzk_dequeue() {
-    pzk_dequeue_t* dq = (pzk_dequeue_t*) calloc(1, sizeof(pzk_dequeue_t));
-    dq->mutex = (pthread_mutex_t*) calloc(1, sizeof(pthread_mutex_t));
-    pthread_mutex_init(dq->mutex, NULL);
-    return dq;
-}
-
-int pzk_dequeue_push(pzk_dequeue_t* dq, void* val) {
+static int pzk_dequeue_push(pzk_dequeue_t* dq, void* val) {
     pthread_mutex_lock(dq->mutex);
     pzk_dequeue_node_t* new = _new_pzk_dequeue_node(val);    
 
@@ -34,7 +27,7 @@ int pzk_dequeue_push(pzk_dequeue_t* dq, void* val) {
     return 0;
 }
 
-int pzk_dequeue_unshift(pzk_dequeue_t* dq, void* val) {
+static int pzk_dequeue_unshift(pzk_dequeue_t* dq, void* val) {
     pthread_mutex_lock(dq->mutex);
     pzk_dequeue_node_t* new = _new_pzk_dequeue_node(val);    
 
@@ -52,7 +45,7 @@ int pzk_dequeue_unshift(pzk_dequeue_t* dq, void* val) {
     return 0;
 }
 
-void* pzk_dequeue_pop(pzk_dequeue_t* dq) {
+static void* pzk_dequeue_pop(pzk_dequeue_t* dq) {
     pthread_mutex_lock(dq->mutex);
     pzk_dequeue_node_t* node;
     pzk_dequeue_node_t* last = dq->last;
@@ -77,7 +70,7 @@ void* pzk_dequeue_pop(pzk_dequeue_t* dq) {
     return value;
 }
 
-void* pzk_dequeue_shift(pzk_dequeue_t* dq) {
+static void* pzk_dequeue_shift(pzk_dequeue_t* dq) {
     pthread_mutex_lock(dq->mutex);
     pzk_dequeue_node_t* node;
     pzk_dequeue_node_t* first = dq->first;
@@ -102,7 +95,7 @@ void* pzk_dequeue_shift(pzk_dequeue_t* dq) {
     return value;
 }
 
-void destroy_pzk_dequeue(pzk_dequeue_t* dq) {
+static void destroy_pzk_dequeue(pzk_dequeue_t* dq) {
     size_t size = dq->size;
     pzk_dequeue_node_t* node;
 
@@ -122,3 +115,18 @@ void destroy_pzk_dequeue(pzk_dequeue_t* dq) {
 
     free(dq);
 }
+
+pzk_dequeue_t* new_pzk_dequeue() {
+    pzk_dequeue_t* dq = (pzk_dequeue_t*) calloc(1, sizeof(pzk_dequeue_t));
+    dq->mutex = (pthread_mutex_t*) calloc(1, sizeof(pthread_mutex_t));
+    pthread_mutex_init(dq->mutex, NULL);
+
+    dq->push    = pzk_dequeue_push;
+    dq->pop     = pzk_dequeue_pop;
+    dq->unshift = pzk_dequeue_unshift;
+    dq->shift   = pzk_dequeue_shift;
+    dq->destroy = destroy_pzk_dequeue;
+
+    return dq;
+}
+
