@@ -1,6 +1,8 @@
 package ZooKeeper::XUnit::Dispatcher::POE;
 use Try::Tiny;
 use Test::Class::Moose;
+with 'ZooKeeper::XUnit::Role::Dispatcher';
+with 'ZooKeeper::XUnit::Role::CheckWait';
 
 sub load_poe {
         require POE::Kernel;
@@ -23,11 +25,16 @@ sub test_startup {
 
 sub new_future { POE::Future->new }
 
+sub new_delay {
+    my ($self, $after, $cb) = @_;
+    require POE::Future;
+    return POE::Future->new_delay($after)
+                      ->on_done($cb);
+}
+
 sub new_dispatcher {
     my ($self, @args) = @_;
     return ZooKeeper::Dispatcher::POE->new(@args);
 }
 
-
-with 'ZooKeeper::XUnit::Role::Dispatcher';
 1;
